@@ -8,8 +8,7 @@ class SCKernel(Kernel):
     language_version = "3.10"
     language_info = {
         'name':'sclang',    
-        'mimetype':'text',
-        'codemirror_mode':'smalltalk' # for now use smalltalk syntax highlighting
+        'codemirror_mode':'sclang' # mode defined in kernel.js
     }
     banner = "SuperCollider Kernel"
 
